@@ -17,15 +17,15 @@ class AptOfflineQtInstallBugList(QtWidgets.QDialog):
         def __init__(self, filepath, parent=None):
             QtWidgets.QWidget.__init__(self, parent)
             self.ui = Ui_AptOfflineQtInstallBugList()
-            
+
             self.bugList = {}
             self.filepath = filepath
-            
+
             self.ui.setupUi(self)
-            self.populateBugList(self.filepath)            
-            
+            self.populateBugList(self.filepath)
+
             self.ui.bugListViewWindow.itemSelectionChanged.connect(self.populateBugListPlainTextEdit)
-            
+
             # Connect the clicked signal of the Browse button to it's slot
             #QtCore.QObject.connect(self.ui.closeButton, QtCore.SIGNAL("clicked()"),
             #                self.reject )
@@ -34,23 +34,23 @@ class AptOfflineQtInstallBugList(QtWidgets.QDialog):
         def populateBugListPlainTextEdit(self):
                 self.ui.bugListplainTextEdit.clear()
                 textItem = str(self.ui.bugListViewWindow.currentItem().text() )
-                
+
                 extractedText = self.bugList[textItem]
-                self.ui.bugListplainTextEdit.appendPlainText(" ".join(extractedText))
-                
+                self.ui.bugListplainTextEdit.appendPlainText((b" ".join(extractedText)).decode('utf-8'))
+
                 myCursor = self.ui.bugListplainTextEdit.textCursor()
                 myCursor.movePosition(myCursor.Start)
                 self.ui.bugListplainTextEdit.setTextCursor(myCursor)
-        
+
         def noBugPopulateBugListPlainTextEdit(self):
                 self.ui.bugListplainTextEdit.clear()
                 self.ui.bugListplainTextEdit.appendPlainText("No Bug Reports Found")
 
         def populateBugList(self, path):
-                
+
                 if os.path.isfile(path):
                         zipFile = zipfile.ZipFile(path, "r")
-                        
+
                         for filename in zipFile.namelist():
                                 if filename.endswith( AptOfflineCoreLib.apt_bug_file_format ):
                                         #INFO: The splitter is use is "{}". Also used at other places
@@ -61,6 +61,8 @@ class AptOfflineQtInstallBugList(QtWidgets.QDialog):
                                         temp.file.flush()
                                         temp.file.seek( 0 ) #Let's go back to the start of the file
                                         for bug_subject_identifier in temp.file.readlines():
+                                                bug_subject_identifier = bug_subject_identifier.decode('utf-8')
+                                                print(bug_subject_identifier)
                                                 if bug_subject_identifier.startswith( 'Subject:' ):
                                                         bug_subject_identifier = str(bugNumber) + ": " + bug_subject_identifier.lstrip("Subject:")
                                                         bug_subject_identifier = bug_subject_identifier.rstrip("\n")
@@ -68,7 +70,7 @@ class AptOfflineQtInstallBugList(QtWidgets.QDialog):
                                                         self.bugList[bug_subject_identifier] = temp.file.readlines()
                                                         break
                                         temp.file.close()
-                                        
+
                 elif os.path.isdir(path):
                         for filename in os.listdir( path ):
                                 if filename.endswith( AptOfflineCoreLib.apt_bug_file_format ):
@@ -76,6 +78,7 @@ class AptOfflineQtInstallBugList(QtWidgets.QDialog):
                                         filename = os.path.join(path, filename)
                                         temp = open(filename, 'r')
                                         for bug_subject_identifier in temp.readlines():
+                                                bug_subject_identifier = bug_subject_identifier.decode('utf-8')
                                                 if bug_subject_identifier.startswith( 'Subject:' ):
                                                         bug_subject_identifier = str(bugNumber) + ": " + bug_subject_identifier.lstrip("Subject:")
                                                         bug_subject_identifier = bug_subject_identifier.rstrip("\n")
@@ -91,9 +94,9 @@ class AptOfflineQtInstallBugList(QtWidgets.QDialog):
                         self.noBugPopulateBugListPlainTextEdit()
                 else:
                         for eachItem in list(self.bugList.keys()):
-                                item = QtGui.QListWidgetItem(eachItem)
+                                item = QtWidgets.QListWidgetItem(eachItem)
                                 self.ui.bugListViewWindow.addItem(item)
-                        
+
 
 if __name__ == "__main__":
         app = QtGui.QApplication(sys.argv)
